@@ -1,6 +1,10 @@
 """
-A collection of routines for doing things like starting
-a server, creating a user. Command line tools.
+Command line tools for TiddlyWeb, accessed via the twanager command line
+script. Each command below is added to the availble twanager commands.
+This list is extensible via twanager_plugins in tidldyweb.config.
+
+Typical commands do things like starting a server, create a user, list
+existing entities.
 """
 
 import sys
@@ -100,7 +104,7 @@ def init(config):
         """Add or update a user to the database: <username> <password> [[role] [role] ...]"""
         try:
             username, password = args[0:2]
-        except (IndexError, ValueError), exc:
+        except (IndexError, ValueError):
             usage('you must include at least a username and password')
 
         try:
@@ -123,7 +127,7 @@ def init(config):
         """Create or update a recipe with the recipe text on stdin: <recipe>"""
         try:
             recipe_name = args[0]
-        except IndexError, exc:
+        except IndexError:
             usage('you must include a recipe name')
 
         from tiddlyweb.model.recipe import Recipe
@@ -138,7 +142,7 @@ def init(config):
         """Create or update a bag with the json text on stdin: <bag>"""
         try:
             bag_name = args[0]
-        except IndexError, exc:
+        except IndexError:
             usage('you must include a bag name')
 
         from tiddlyweb.model.bag import Bag
@@ -155,7 +159,7 @@ def init(config):
         """Import a single tiddler into an existing bag from stdin: <bag> <tiddler>"""
         try:
             bag_name, tiddler_name = args[0:3]
-        except (IndexError, ValueError), exc:
+        except (IndexError, ValueError):
             usage('you must include a tiddler and bag name')
 
         from tiddlyweb.model.tiddler import Tiddler
@@ -168,9 +172,11 @@ def init(config):
 
     @make_command()
     def lusers(args):
-        """List all the users on the system"""
+        """List all the users on the system. [<user> <user> <user>] to limit."""
         store = _store()
-        users = store.list_users()
+        users = [User(name) for name in args]
+        if not users:
+            users = store.list_users()
         for user in users:
             user = store.get(user)
             print user.usersign.encode('utf-8'), ', '.join(role.encode('utf-8')
@@ -220,11 +226,9 @@ def init(config):
                 listed_bag = store.get(listed_bag)
                 owner = listed_bag.policy.owner or ''
                 print listed_bag.name.encode('utf-8'), owner.encode('utf-8')
-                tiddlers = listed_bag.list_tiddlers()
+                tiddlers = store.list_bag_tiddlers(listed_bag)
                 for listed_tiddler in tiddlers:
-                    listed_tiddler = store.get(listed_tiddler)
-                    print '\t%s %s' % (listed_tiddler.title.encode('utf-8'),
-                            listed_tiddler.modifier.encode('utf-8'))
+                    print '\t%s' % listed_tiddler.title.encode('utf-8')
         except NoBagError, exc:
             usage('unable to inspect bag %s: %s' % (listed_bag.name, exc))
 
